@@ -1,8 +1,8 @@
-from argparse import ArgumentParser, FileType, RawDescriptionHelpFormatter
+from argparse import ArgumentDefaultsHelpFormatter, ArgumentParser, FileType
 from json import dumps, loads
 from json.decoder import JSONDecodeError
 from sys import stdout
-from typing import BinaryIO
+from typing import BinaryIO, TextIO
 
 from . import doc_split, usage, version
 from .extras import json_utf8_decode, json_utf8_encode
@@ -48,59 +48,66 @@ def _loads(string: str) -> str:
         return string
 
 
-def rpc_list(handle: BinaryIO, device: str, baudrate: int, wait: int) -> None:
+def rpc_list(
+        handle: BinaryIO, device: str, baudrate: int, wait: int, save: TextIO
+        ) -> None:
     """List the device methods.
 
     :arg handle: Output handle.
     :arg device: Device.
     :arg baudrate: Baud rate.
     :arg wait: Time in seconds before communication starts.
+    :arg save: Interface definition file.
     """
     with Interface(device, baudrate, wait) as interface:
-        for method in interface.methods.values():
-            handle.write(_describe_method(method) + '\n\n\n')
+        if not save:
+            for method in interface.device['methods'].values():
+                handle.write(_describe_method(method) + '\n\n\n')
+        else:
+            interface.save(save)
 
 
 def rpc_call(
-        handle: BinaryIO, device: str, baudrate: int, wait: int, name: str,
-        args: list) -> None:
+        handle: BinaryIO, device: str, baudrate: int, wait: int, load: TextIO,
+        name: str, args: list) -> None:
     """Execute a method.
 
     :arg handle: Output handle.
     :arg device: Device.
     :arg baudrate: Baud rate.
     :arg wait: Time in seconds before communication starts.
+    :arg load: Interface definition file.
     :arg name: Method name.
     :arg args: Method parameters.
     """
     args_ = list(map(lambda x: json_utf8_encode(_loads(x)), args))
 
-    with Interface(device, baudrate, wait) as interface:
+    with Interface(device, baudrate, wait, True, load) as interface:
         result = interface.call_method(name, *args_)
 
         if result is not None:
             handle.write('{}\n'.format(dumps(json_utf8_decode(result))))
 
 
-def main() -> None:
-    """Main entry point."""
+def _arg_parser() -> object:
+    """Command line argument parsing."""
     output_parser = ArgumentParser(add_help=False)
     output_parser.add_argument(
         '-o', dest='handle', metavar='OUTPUT', type=FileType('w'),
-        default=stdout, help='output file')
+        default='-', help='output file')
 
     common_parser = ArgumentParser(add_help=False, parents=[output_parser])
     common_parser.add_argument(
-        'device', metavar='DEVICE', type=str, help='device (%(type)s)')
+        'device', metavar='DEVICE', type=str, help='device')
     common_parser.add_argument(
         '-b', dest='baudrate', type=int, default=9600,
-        help='baud rate (%(type)s default=%(default)s)')
+        help='baud rate')
     common_parser.add_argument(
         '-w', dest='wait', type=int, default=2,
-        help='time before communication starts (%(type)s default=%(default)s)')
+        help='time before communication starts')
 
     parser = ArgumentParser(
-        formatter_class=RawDescriptionHelpFormatter,
+        formatter_class=ArgumentDefaultsHelpFormatter,
         description=usage[0], epilog=usage[1])
     parser.add_argument(
         '-v', action='version', version=version(parser.prog))
@@ -108,16 +115,31 @@ def main() -> None:
     subparsers.required = True
 
     subparser = subparsers.add_parser(
-        'list', parents=[common_parser], description=doc_split(rpc_list))
+        'list', formatter_class=ArgumentDefaultsHelpFormatter,
+        parents=[common_parser], description=doc_split(rpc_list))
+    subparser.add_argument(
+        '-s', dest='save', type=FileType('w'), default=None,
+        help='interface definition file')
     subparser.set_defaults(func=rpc_list)
 
     subparser = subparsers.add_parser(
-        'call', parents=[common_parser], description=doc_split(rpc_call))
-    subparser.set_defaults(func=rpc_call)
+        'call', formatter_class=ArgumentDefaultsHelpFormatter,
+        parents=[common_parser], description=doc_split(rpc_call))
     subparser.add_argument(
         'name', metavar='NAME', type=str, help='command name')
     subparser.add_argument(
         'args', metavar='ARG', type=str, nargs='*', help='command parameter')
+    subparser.add_argument(
+        '-l', dest='load', type=FileType('r'), default=None,
+        help='interface definition file')
+    subparser.set_defaults(func=rpc_call)
+
+    return parser
+
+
+def main() -> None:
+    """Main entry point."""
+    parser = _arg_parser()
 
     try:
         args = parser.parse_args()
